@@ -8,10 +8,11 @@ Created on Thu Nov 09 13:09:10 2017
 from __future__ import absolute_import
 
 name = "option pricer"
+version = "0.1.1"
 
 from .IRS import IRSPricer_class as IRSPricer
 from .Vanilla import VanillaPricer_Class as VanillaPricer
 from .Asian import AsianPricer_class as AsianPricer
 from .iData import save_json, read_json
-
+from .iDate import timefn
 
